import { type InnerShadowProps } from './types';
import type { LINEAR_DIRECTION } from './types';
/**
 *  createStyles generates the StyleSheet object for the canvas
 *
 * @param width - The width of the canvas
 * @param height - The height of the canvas
 * @returns The StyleSheet object for the canvas
 */
export declare function createStyles({ width, height, }: {
    width: number;
    height: number;
}): {
    canvas: {
        position: "absolute";
        left: number;
        top: number;
        backgroundColor: string;
        width: number;
        height: number;
    };
};
/**
 * getBackgroundColor retrieves the final background color
 * from either:
 *   1) props.backgroundColor
 *   2) style.backgroundColor
 *   3) DEFAULT_BACKGROUND_COLOR
 *
 * This ensures there is always a valid color for the component’s background.
 */
export declare function getBackgroundColor(props: Pick<InnerShadowProps, 'backgroundColor' | 'style' | 'children'>): string;
/**
 * getShadowProperty determines the final configuration for both
 * the main shadow and any reflected light. It merges default values
 * with provided props to form a complete “shadow settings” object.
 *
 * - shadowOffset / reflectedLightOffset: how far the shadows/highlights
 *   are shifted in x and y.
 * - shadowColor / reflectedLightColor: colors used for each effect.
 * - shadowBlur / reflectedLightBlur: blur radius for the softness/spread
 *   of the shadow or highlight.
 *
 * @param props - The props object containing shadow-related settings.
 * @returns {
 * shadowOffset, reflectedLightOffset, shadowColor, reflectedLightColor, shadowBlur, reflectedLightBlur}
 */
export declare function getShadowProperty(props: Omit<InnerShadowProps, 'children'>): {
    shadowOffset: {
        width: number;
        height: number;
    };
    reflectedLightOffset: {
        width: number;
        height: number;
    };
    shadowColor: string;
    reflectedLightColor: string;
    shadowBlur: number;
    reflectedLightBlur: number;
};
interface OuterShadowOffsetProps {
    inset?: boolean;
    shadowOffset: {
        width: number;
        height: number;
    };
    shadowColor: string;
    shadowBlur: number;
}
export declare function createOuterShadowOffset({ inset, shadowColor, shadowOffset, shadowBlur, }: OuterShadowOffsetProps): {
    shadowColor: string;
    shadowOffset: {
        width: number;
        height: number;
    };
    shadowOpacity: number;
} | null;
interface GetLinearDirectionProps {
    width: number;
    height: number;
    from: LINEAR_DIRECTION;
    to: LINEAR_DIRECTION;
}
export declare function getLinearDirection({ width, height, from, to, }: GetLinearDirectionProps): {
    start: import("@shopify/react-native-skia").SkPoint;
    end: import("@shopify/react-native-skia").SkPoint;
};
export {};
//# sourceMappingURL=utils.d.ts.map